package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.*;
import com.hp.user.client.service.StationService;
import com.hp.user.service.dao.StationMapper;
import com.hp.user.service.entity.Station;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 站点信息 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class StationServiceImpl implements StationService {
    @Autowired
    private StationMapper stationMapper;

    @Override
    public Result insert(StationVO station) {
        Station temp = new Station();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(station, temp);
            flag = stationMapper.insert(temp);
        }catch (Exception e){

        }
        // 判断数据库操作是否成功
        if(SqlHelper.retBool(flag)){
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("添加失败");
        }
        return result;
    }

    @Override
    public Result delete(String stationId) {
        // 将deleted字段设置为1
        Station temp;
        int flag=0;
        Result result = new Result();
        try{
            temp = stationMapper.selectById(stationId);
            if(temp==null){
                result.setCode("-1");
                result.setMessage("未查找到此站点");
                return result;
            }
            temp.setSysDeleted((short) 1);
            flag = stationMapper.updateById(temp);
        }catch (Exception e){

        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }

    @Override
    public Result update(StationVO station) {
        Station temp = new Station();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(station, temp);
            flag = stationMapper.updateById(temp);
        }catch (Exception e){

        }
        // 判断数据库操作是否成功
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("更新失败");
        }
        return result;
    }

    @Override
    public DataResult<StationVO> queryStationByStationId(String stationId) {
        StationVO stationVO = new StationVO();
        DataResult<StationVO> result = new DataResult<>();
        try{
            Station temp = stationMapper.selectById(stationId);
            if (temp == null || temp.getSysDeleted() == 1) {
                result.setCode("-1");
                result.setMessage("站点不存在/已删除");
                return result;
            }
            else {
                BeanUtils.copyProperties(temp, stationVO);
                result.setCode("0");
                result.setData(stationVO);
            }
        }catch (Exception e){

        }
        return result;
    }

    @Override
    public DataResult<StationVO> queryStationByStationName(String name) {
        StationVO stationVO = new StationVO();
        DataResult<StationVO> result= new DataResult<>();
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        try{
            wrapper.like("name", name);
            wrapper.eq("sys_deleted", 0);
            Station station = stationMapper.selectOne(wrapper);
            if (station == null) {
                result.setCode("-1");
                result.setMessage("站点不存在/已删除");
                return result;
            }
            else {
                BeanUtils.copyProperties(station, stationVO);
                result.setCode("0");
                result.setData(stationVO);
            }
        }catch (Exception e){

        }
        return result;
    }

    @Override
    public PageResult<StationVO> getStationsPage(Long current, Integer size) {
        PageResult<StationVO> result = new PageResult<>();
        List<StationVO> stationVOList = new ArrayList<>();
        IPage<Station> page = new Page<>(current, size);
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        try{
            wrapper.orderByDesc("sys_create_time");
            wrapper.eq("sys_deleted", 0);
            stationMapper.selectPage(page, wrapper);
            List<Station> stations = page.getRecords();
            StationVO temp;
            for (Station station : stations) {
                temp = new StationVO();
                BeanUtils.copyProperties(station, temp);
                stationVOList.add(temp);
            }
            result.setDataList(stationVOList);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
            return result;
        }catch (Exception e){

        }
        return result;
    }
}
